@@ -1,5 +1,5 @@
 #-------------------------------------------------------------------------------
-# Licence:
+# MIT License:
 # Copyright (c) 2012-2020 Valerio for Gecosistema S.r.l.
 #
 # The above copyright notice and this permission notice shall be
@@ -27,7 +27,8 @@ from .module_types import *
 from .module_geolocate import *
 from .module_GDAL2Numpy import *
 from .module_Numpy2GTiff import *
-from .module_metadata import *
+from .module_cog import *
+from .module_meta import *
 from .module_ogr import *
 from .module_features import *
 from .module_esri_shape import *
@@ -37,10 +38,14 @@ from .module_http import *
 from .module_open import get
 from .rasterlike import RasterLike
 from .rasterizelike import RasterizeLike
+from .polygonize import Polygonize
+from .dissolve import Dissolve
 from .module_gdal import *
 from .gdalwarp import gdalwarp
 from .gdal_translate import gdal_translate
+from .gdal_merge import gdal_merge
 from .module_log import *
 from .module_xml import *
 from .module_extrusion import *
+from .module_secrets import *
 
