@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------------
-# Licence:
+# MIT License:
 # Copyright (c) 2012-2021 Luzzi Valerio
 #
 # The above copyright notice and this permission notice shall be
@@ -23,12 +23,15 @@
 # Created:     16/06/2021
 # -------------------------------------------------------------------------------
 import os
+import subprocess
 from osgeo import gdal, gdalconst
 from .filesystem import juststem, tempfilename, listify
-from .module_Numpy2GTiff import GTiff2Cog
-from .module_ogr import SameSpatialRef, AutoIdentify, GetSpatialRef
+from .module_ogr import SameSpatialRef, GetSpatialRef
+from .module_meta import GetNoData, GDALFixNoData
+from .module_Numpy2GTiff import CalculateStats
 from .module_s3 import *
 from .gdal_translate import dtypeOf
+from .module_log import Logger
 
 
 def resampling_method(method):
@@ -59,10 +62,12 @@ def gdalwarp(filelist,
              resampleAlg="near",
              format="GTiff",
              ot=None,
-             dstNodata=None):
+             dstNodata=None,
+             stats=True):
     """
     gdalwarp
     """
+
     t0 = now()
 
     filelist = listify(filelist)
@@ -77,19 +82,20 @@ def gdalwarp(filelist,
 
     format = format.lower() if format else "gtiff"
 
-    creation_options = co.get(format, [])
-
     filetmp = tempfilename(prefix="gdalwarp/tmp_", suffix=".tif")
+    # inplace gdalwarp, give the fileout as the first file in the list
+    if fileout is None and len(filelist) > 0:
+        fileout = filelist[0]
     fileout = fileout if fileout else filetmp
 
     filelist_tmp = copy(filelist)
 
     kwargs = {
-        #"format": "GTiff",
+        # "format": "GTiff",
+        # "creationOptions": ["BIGTIFF=YES", "TILED=YES", "BLOCKXSIZE=512", "BLOCKYSIZE=512", "COMPRESS=LZW"],
         "format": format,
-        "creationOptions": creation_options,
-        #"warpOptions": ["NUM_THREADS=ALL_CPUS", "GDAL_CACHEMAX=512"],
-        #"dstNodata": dstNodata,
+        "creationOptions": co.get(format, []),
+        # "warpOptions": ["NUM_THREADS=ALL_CPUS", "GDAL_CACHEMAX=512"],
         "resampleAlg": resampling_method(resampleAlg),
         "multithread": True,
     }
@@ -100,8 +106,8 @@ def gdalwarp(filelist,
     # outputType = [-ot {Byte/Int16/UInt16/UInt32/Int32/Float32/Float64/CInt16/CInt32/CFloat32/CFloat64}]
     if ot and ot in dtypeOf:
         ot = ot.lower() if isinstance(ot, str) else ot
-        kwargs["outputType"] = dtypeOf[ot] #gdal.GDT_Float32
-  
+        kwargs["outputType"] = dtypeOf[ot]  # gdal.GDT_Float32
+
     # pixelsize
     pixelsize = listify(pixelsize)
     if len(pixelsize) == 1 and pixelsize[0] != 0:
@@ -114,7 +120,6 @@ def gdalwarp(filelist,
     if len(filelist) == 1 and SameSpatialRef(filelist_tmp[0], dstSRS):
         Logger.debug(f"Avoid reprojecting {filelist[0]}")
     elif dstSRS:
-        #kwargs["dstSRS"] = AutoIdentify(dstSRS)
         kwargs["dstSRS"] = GetSpatialRef(dstSRS)
 
     cutline_tmp = None
@@ -126,26 +131,33 @@ def gdalwarp(filelist,
     elif isinstance(cutline, (tuple, list)) and len(cutline) == 4:
         kwargs["outputBounds"] = listify(cutline)
 
-    # inplace gdalwarp, give the fileout as the first file in the list
-    if fileout is None and len(filelist) > 0:
-        fileout = filelist[0]
-
     # assert that the folder exists
     os.makedirs(justpath(filetmp), exist_ok=True)
-    gdal.Warp(filetmp, filelist_tmp, **kwargs)
-    
-    Logger.debug(f"gdalwarp: converted to {filetmp} in {total_seconds_from(t0)} s.")
-   
-    # if format == "cog":
-    #     # inplace conversion
-    #     t1 = now()
-    #     GTiff2Cog(filetmp)
-    #     Logger.debug(
-    #         f"GTiff2Cog: converted {filetmp}  in {total_seconds_from(t1)} s.")
+    try:
+        gdal.UseExceptions()
+        gdal.PushErrorHandler('CPLQuietErrorHandler')
+        gdal.Warp(filetmp, filelist_tmp, **kwargs)
+    except Exception as ex:
+        Logger.error(ex)
+    finally:
+        gdal.PopErrorHandler()
 
-    # move the file to the output
+    # patch notdata value
+    if dstNodata is not None and GetNoData(filetmp) != dstNodata:
+        Logger.debug(f"gdalwarp: fixing nodata value to {dstNodata}")
+        GDALFixNoData(filetmp, format=format, nodata = dstNodata)
+    
+    if stats and isfile(filetmp):
+        #os.system(f'gdalinfo -stats "{filetmp}"')
+        subprocess.run(["gdalinfo", "-stats", filetmp], shell=False, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)
+        move(f"{filetmp}.aux.xml", f"{fileout}.aux.xml")
+
+    # moving the filetmp to fileout
     move(filetmp, fileout)
 
+    Logger.debug(
+        f"gdalwarp: converted to {fileout} in {total_seconds_from(t0)} s.")
+
     # clean the cutline file
     remove(cutline_tmp)
 
