@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------------
-# Licence:
+# MIT License:
 # Copyright (c) 2012-2021 Luzzi Valerio
 #
 # The above copyright notice and this permission notice shall be
@@ -42,8 +42,9 @@ def GetFeatures(fileshp, filter=None, format=None):
     ds = OpenShape(fileshp)
     if ds:
         # filter features by fid
+        filter = listify(filter)
         if filter and len(filter) > 0:
-            res = [ds.GetLayer().GetFeature(fid) for fid in listify(filter)]
+            res = [ds.GetLayer().GetFeature(fid) for fid in filter]
         else:
             res = ds.GetLayer()
 
@@ -248,10 +249,6 @@ def Transform(fileshp, t_srs, fileout=None):
 
     fileout = fileout if fileout else f"{tempfile.gettempdir()}/{md5sum(fileshp)}_{md5text(t_srs.GetName())}.shp"
 
-    # if isshape(fileout):
-    #     Logger.debug("Using cached file:<%s>..." % fileout)
-    #     return fileout
-
     ds = OpenShape(fileshp)
     if ds:
         layer = ds.GetLayer()
@@ -277,16 +274,17 @@ def Transform(fileshp, t_srs, fileout=None):
         # Copy and transform each feature
         for feature in layer:
             transformed = feature.GetGeometryRef()
-            transformed.Transform(transform)
+            if transformed:
+                transformed.Transform(transform)
 
-            geom = ogr.CreateGeometryFromWkb(transformed.ExportToWkb())
-            defn = outlayer.GetLayerDefn()
-            new_feature = ogr.Feature(defn)
-            for j in range(defn.GetFieldCount()):
-                new_feature.SetField(j, feature.GetField(j))
-            new_feature.SetGeometry(geom)
-            outlayer.CreateFeature(new_feature)
-            new_feature = None
+                geom = ogr.CreateGeometryFromWkb(transformed.ExportToWkb())
+                defn = outlayer.GetLayerDefn()
+                new_feature = ogr.Feature(defn)
+                for j in range(defn.GetFieldCount()):
+                    new_feature.SetField(j, feature.GetField(j))
+                new_feature.SetGeometry(geom)
+                outlayer.CreateFeature(new_feature)
+                new_feature = None
 
         ds, dw = None, None
         return fileout
@@ -336,6 +334,27 @@ def QueryByPoint(file_shp, point):
     return closest_geometry_id
 
 
+def QueryByOsmid(file_shp, osmid):
+    """
+    QueryByAttribute - Search for alla features that have the attribute osmid=value
+    fileshp: shapefile path
+    osmid: the value of the attribute
+    """
+    # Open the shapefile
+    features = []
+    ds = OpenShape(file_shp, 0)
+    if ds:
+        layer = ds.GetLayer(0)
+        layer.ResetReading()
+        layer.SetAttributeFilter(f"osmid={osmid}")
+        features = [feature for feature in layer]
+        ds = None
+        
+    return features
+
+
+
+
 def CreateGeometryFromJson(geojson):
     """
     CreateGeometryFromJson
@@ -395,7 +414,6 @@ def SaveFeatures(features, fileshp):
             
             # properties = { "dtm":1.5 , "hello":"world"}
             for name in properties:
-                print(f"<{name}>")
                 dtype, dwidth = (f"{properties[name]}:0").split(":")
                 p, w = math.modf(float(dwidth))
                 p, w = int(p), int(w)
