@@ -23,4 +23,18 @@ def parseFloat(text):
     try:
         return float(f"{text}")
     except ValueError:
-        return None
\ No newline at end of file
+        return None
+    
+
+def isstring(text):
+    """
+    isstring
+    """
+    return isinstance(text, (str,))
+
+
+def isarray(text):
+    """
+    isarray
+    """
+    return isinstance(text, (list, tuple))
\ No newline at end of file
